@@ -30,11 +30,6 @@ from taskindicator import util
 FREQUENCY = 1  # seconds
 
 
-def get_task_info(uuid):
-    out = util.run_command(["task", uuid, "export"])
-    return json.loads(out)
-
-
 def get_program_path(command):
     for path in os.getenv("PATH").split(os.pathsep):
         full = os.path.join(path, command)
@@ -121,7 +116,8 @@ class Checker(object):
                 self.menu.remove(item)
         self.task_items = []
 
-        data = self.database.get_tasks()
+        data = [t for t in self.database.get_tasks()
+            if t["status"] == "pending"]
 
         for task in sorted(data, key=self.task_sort)[:10]:
             item = gtk.CheckMenuItem(self.format_menu_label(task), use_underline=False)
@@ -149,10 +145,12 @@ class Checker(object):
 
     def task_sort(self, task):
         """Returns the data to sort tasks by."""
-        # print("%s %s" % (task["urgency"], task["description"]), file=sys.stderr)
-        is_pinned = task.get("priority") == "H"  # "pin" in task.get("tags", [])
+        is_pinned = "pin" in task.get("tags", [])
         is_running = "start" in task
-        return -is_running, -is_pinned, -float(task["urgency"])
+        is_endless = "endless" in task.get("tags", [])
+        pri = {"H":3, "M": 2, "L": 1}.get(task.get("priority"), 0)
+        return (-is_running, -is_pinned, is_endless, -pri,
+            -float(task.get("urgency", 0)))
 
     def on_add_task(self, widget):
         self.dialog.show_task({"uuid": None, "status": "pending",
@@ -165,7 +163,7 @@ class Checker(object):
         self.search_dialog.show_all()
 
     def on_search_callback(self, uuid):
-        self.dialog.show_task(get_task_info(uuid))
+        self.dialog.show_task(util.get_task_info(uuid))
 
     def on_task_toggle(self, widget):
         if self.toggle_lock:
@@ -237,7 +235,8 @@ class Checker(object):
     def update_status(self):
         """Changes the indicator icon and text label according to running
         tasks."""
-        tasks = [t for t in self.database.get_tasks() if "start" in t]
+        tasks = [t for t in self.database.get_tasks()
+            if t["status"] == "pending" and "start" in t]
 
         if not tasks:
             self.indicator.set_label("Idle")
@@ -253,15 +252,11 @@ class Checker(object):
             self.indicator.set_label(msg)
 
     def get_duration(self):
-        now = datetime.datetime.utcnow()
-
-        duration = datetime.timedelta()
+        duration = 0
         for task in self.database.get_tasks():
-            if "start" in task:
-                ts = datetime.datetime.strptime(task["start"], "%Y%m%dT%H%M%SZ")
-                duration += (now - ts)
-
-        return int(duration.total_seconds())
+            if task["status"] == "pending" and "start" in task:
+                duration += task.get_current_runtime()
+        return duration
 
     def format_duration(self, seconds):
         minutes = seconds / 60
